pub struct PathStringOptions {
pub normal_separator: &'static str,
pub reverse_separator: &'static str,
pub ignore_process: bool,
pub skip_process: bool,
pub ignore_thread: bool,
pub include_thread_number_in_path: bool,
pub reversed: bool,
pub prefix: &'static str,
}Fields
normal_separator: &'static strreverse_separator: &'static strignore_process: boolStop when reaching a ScopeKind::Process
skip_process: boolSkip showing the process completely (ignore_process just
stops before it and shows a placeholder)
ignore_thread: boolStop when reaching a ScopeKind::Thread
include_thread_number_in_path: boolAdd thread number (0..) in path strings
reversed: boolWhether to show the top of the tree left (default) or the leafs left (reversed)
prefix: &'static strA prefix to distinguish this kind of path from others (feel
free to use “”). Only used with ignore_process and
ignore_thread!