pub struct Span<'t> {
pub parent: Option<SpanId<'t>>,
pub children: MicroVec<SpanId<'t>>,
pub data: SpanData<'t>,
}Fields
parent: Option<SpanId<'t>>children: MicroVec<SpanId<'t>>data: SpanData<'t>Implementations
Sourceimpl<'t> Span<'t>
impl<'t> Span<'t>
Sourcepub fn end_mut(&mut self) -> Option<(&mut Option<&'t Timing>, ScopeKind)>
pub fn end_mut(&mut self) -> Option<(&mut Option<&'t Timing>, ScopeKind)>
Also returns the ScopeKind, since you want to verify that at
the same time as mutating the end field.
Sourcepub fn assert_consistency(&self)
pub fn assert_consistency(&self)
Checks that the pn on the start and end timings
match. Panics if they don’t.
pub fn pn(&self) -> Option<&'t str>
Sourcepub fn path_string(
&self,
opts: &PathStringOptions,
db: &LogDataTree<'t>,
out_prefix: &mut String,
out_main: &mut String,
)
pub fn path_string( &self, opts: &PathStringOptions, db: &LogDataTree<'t>, out_prefix: &mut String, out_main: &mut String, )
Show the path to a node in the tree (towards the right, show
the child node; can also be in reverse (via opts): towards the
right, show the parents up the tree). out_prefix receives
the prefix (always meant to be shown on the left), out_main
receives the main part of the path (in reversed or normal
form). The outputs are not cleared by this method! The idea
is to out_prefix.push_str(&out_main) after this call, then
clear both buffers before re-using them.
pub fn start_and_end(&self) -> Option<(&'t Timing, &'t Timing)>